package com.adhi.adhij;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * The Date utility class
 * @author DKRISHNA
 *
 */
public class DateUtil
{
	/**
	 * converts the string to a date
	 * @param dateStr the date string to be converted
	 * @return the converted date
	 * @throws ParseException if the string cannot be parsed
	 */
	public static Date stringToDate(String dateStr) throws ParseException
	{
		SimpleDateFormat dateFormatter = new SimpleDateFormat("yyyy-MM-dd");
		Date date = null;
		if(dateStr != null && !"".equals(dateStr))
		{
			date = dateFormatter.parse(dateStr);
		}
		return date;
	}
	
	/**
	 * converts the date to a string
	 * @param date the date to be converted
	 * @return the converted string of the format yyyy-MM-dd
	 */
	public static String dateToString(Date date)
	{
		return dateToString(date, "yyyy-MM-dd");
	}
	
	/**
	 * converts the date to a string
	 * @param date the date to be converted
	 * @return the converted string of the format yyyy-MM-dd
	 */
	public static String dateToStringMMM(Date date)
	{
		return dateToString(date, "dd-MMM-yyyy");
	}

	/**
	 * converts a date to a string
	 * @param date the date to be converted
	 * @return the converted string of the format yyyy-MM-dd HH:mm:ss
	 */
	public static String dateTimeToString(Date date)
	{
		return dateToString(date, "yyyy-MM-dd HH:mm:ss");
	}
		
	/**
	 * convert the string to a date using a format
	 * @param date the date
	 * @param pattern the format pattern
	 * @return the converted date using the pattern
	 */
	public static String dateToString(Date date, String pattern)
	{
		SimpleDateFormat dateFormatter = new SimpleDateFormat(pattern);
		String dateStr = null;
		if(date != null && !"".equals(dateStr))
		{
			dateStr = dateFormatter.format(date);
		}
		return dateStr;
	}
	
	/**
	 * converts the string to a date
	 * @param dateStr the date string
	 * @return the converted date using the format dd-MMM-yyyy
	 * @throws ParseException if the string cannot be parsed
	 */
	public static Date stringMMMToDate(String dateStr) throws ParseException
	{
		SimpleDateFormat dateFormatter = new SimpleDateFormat("dd-MMM-yyyy");
		Date date = null;
		if(dateStr != null && !"".equals(dateStr))
		{
			date = dateFormatter.parse(dateStr);
		}
		return date;
	}
	
}