package com.adhi.adhij;

import java.io.Serializable;

/**
 * The value objects holds the attributes of a business object.  Value objects are 
 * always contained within a business object.  Value objects are passed into a data
 * access object for database operation.  These are passed to the clients of business
 * objects and services when they need information or state about a business object.
 * @author DKRISHNA
 *
 * 
 */
public abstract class ValueObject implements Serializable, Comparable
{
	private short mode;
	private long id;
	private String name;
	
	/**
	 * returns the mode
	 * @return the mode
	 */
	public short getMode() {
		return mode;
	}

	/**
	 * sets the mode
	 * @param s the mode
	 */
	public void setMode(short s) {
		mode = s;
	}

	/**
	 * returns the object id
	 * @return the object id
	 */
	public long getId() {
		return id;
	}

	/**
	 * returns the object name
	 * @return the object name
	 */
	public String getName() {
		return name;
	}

	/**
	 * sets the object id
	 * @param l the object id
	 */
	public void setId(long l) {
		id = l;
	}

	/**
	 * sets the object name
	 * @param string the object name
	 */
	public void setName(String string) {
		name = string;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object arg0) {
		ValueObject vo = (ValueObject)arg0;
		boolean ret = false;
		if(vo != null)
		{
			ret = (getId() == vo.getId());
		}
		return ret;
	}
	
	/**
	 * returns the cloned value object
	 * @param vo the cloned value object
	 * @return the cloned value object
	 */
	public Object  clone(ValueObject vo)
	{
		vo.setId(getId());
		vo.setMode(getMode());
		vo.setName(getName());
	 return vo ;
	}
	
	/**
	 * the compareto method for object comparison
	 */
	public int compareTo(Object obj)
	{
		int ret = 1;
		ValueObject vo = (ValueObject)obj;	
		if(vo != null)
		{
			if(id > vo.getId()) ret = 1;
			else if(id < vo.getId()) ret = -1;
			else ret = 0;
		}
		return ret;
	}

};